@@ -3,7 +3,7 @@ from pandas_datareader import wb
 import pandas as pd
 import numpy as np
 import requests
-
+import yfinance as yf
 
 USER_AGENT = {
     "User-Agent": (
@@ -46,7 +46,7 @@ class FinData:
         df["rstd"] = df["Adj Close"].rolling(window=20).std()
         df["bollinger_upper_band"] = df["20sma"] + 2 * df["rstd"]
         df["bollinger_lower_band"] = df["20sma"] - 2 * df["rstd"]
-        df["Daily Return"] = df["Adj Close"].pct_change()
+        df["Daily Return"] = df["Adj Close"].pct_change(1)
         return df
 
     def get_gdp(self, start, end):
@@ -77,6 +77,7 @@ class FinData:
             .reset_index()
         )
         df = self._build_df(df)
+        df = df.set_index("Date")
         df = df.rename(
             columns={"DEXUSEU": "USD/EU", "DEXJPUS": "USD/YEN", "DEXCHUS": "USD/YUAN"}
         )
@@ -95,7 +96,6 @@ class FinData:
             "FEDFUNDS",
             "PAYEMS",
             "DCOILWTICO",
-            "GOLDAMGBD228NLBM",
             "PALLFNFINDEXQ",
         ]
         df = (
@@ -159,3 +159,19 @@ class FinData:
         df["Date"] = pd.to_datetime(df["time-tag"], format="%Y-%m")
         df = df.set_index("Date")
         return df
+    
+    @staticmethod
+    def get_pi_cycles(dates):
+        """
+            input: dates = {'Date': ["2007-10-11", "2008-09-16", "2020-02-24"]}
+            Each wave is built on 6 8.6 mini waves to complete 51.6 major wave
+        """
+        df = pd.DataFrame(data=dates)
+        df["Date"] = pd.to_datetime(df["Date"])
+        df["2.15Years"] = df["Date"] + pd.DateOffset(days=913)
+        df["4.3Years"] = df["Date"] + pd.DateOffset(days=1571)
+        df["8.6Years"] = df["Date"] + pd.DateOffset(days=3141)
+        df["17.2Years"] = df["Date"] + pd.DateOffset(days=6282)
+        df["34.4Years"] = df["Date"] + pd.DateOffset(days=12564)
+        df["51.6Years"] = df["Date"] + pd.DateOffset(days=18847)
+        return df
\ No newline at end of file
